import _extends from "@babel/runtime/helpers/esm/extends";
import { useEffect } from 'react';
import Hls from 'hls.js';
var useInitHlsEffect = function useInitHlsEffect(_ref) {
  var autoPlay = _ref.autoPlay,
    hlsConfig = _ref.hlsConfig,
    playerRef = _ref.playerRef,
    src = _ref.src,
    timeOffset = _ref.timeOffset;
  useEffect(function () {
    var hls;
    var startOffsetConfig = timeOffset ? {
      startPosition: timeOffset
    } : {};
    function _initPlayer() {
      if (hls !== undefined) {
        hls.destroy();
      }
      var newHls = new Hls(_extends({
        enableWorker: false
      }, hlsConfig, startOffsetConfig));
      if (playerRef.current !== null) {
        newHls.attachMedia(playerRef.current);
      }
      newHls.on(Hls.Events.MEDIA_ATTACHED, function () {
        newHls.loadSource("" + src);
        newHls.on(Hls.Events.MANIFEST_PARSED, function () {
          if (autoPlay) {
            var _playerRef$current;
            /* eslint-disable no-console */
            playerRef == null ? void 0 : (_playerRef$current = playerRef.current) == null ? void 0 : _playerRef$current.play().catch(function () {
              return console.log('Unable to autoplay prior to user interaction with the dom.');
            });
          }
        });
      });
      newHls.on(Hls.Events.ERROR, function (event, data) {
        if (data.fatal) {
          switch (data.type) {
            case Hls.ErrorTypes.NETWORK_ERROR:
              newHls.startLoad();
              break;
            case Hls.ErrorTypes.MEDIA_ERROR:
              newHls.recoverMediaError();
              break;
            default:
              _initPlayer();
              break;
          }
        }
      });
      hls = newHls;
    }

    // Check for Media Source support
    if (Hls.isSupported()) {
      _initPlayer();
    }
    return function () {
      if (hls !== undefined) {
        hls.destroy();
      }
    };
  }, [autoPlay, hlsConfig, playerRef, src, timeOffset]);
};
export default useInitHlsEffect;