import { useCallback, useEffect, useRef } from 'react';
import Player from '@vimeo/player';
var ONE_SECOND = 1000;
var useTimeLimitCheck = function useTimeLimitCheck(_ref) {
  var playerRef = _ref.playerRef,
    timeLimit = _ref.timeLimit,
    timeOffset = _ref.timeOffset;
  var checkTimeLimitInterval = useRef(null);
  var player = useRef(null);
  var stopTimeLimitInterval = useCallback(function () {
    if (checkTimeLimitInterval.current === null) return;
    clearInterval(checkTimeLimitInterval.current);
    checkTimeLimitInterval.current = null;
  }, [checkTimeLimitInterval]);
  var startTimeLimitInterval = useCallback(function () {
    stopTimeLimitInterval();
    if (timeLimit === undefined) return;
    checkTimeLimitInterval.current = setInterval(function () {
      player.current.getCurrentTime().then(function (currentTime) {
        var isTimeLimitReached = currentTime >= timeLimit && timeLimit !== undefined;
        if (isTimeLimitReached) {
          player.current.pause();
          player.current.setCurrentTime(timeOffset || 0);
        }
      });
    }, ONE_SECOND);
  }, [checkTimeLimitInterval, player, stopTimeLimitInterval, timeLimit, timeOffset]);
  useEffect(function () {
    player.current = new Player(playerRef.current);
    player.current.on('play', function () {
      return startTimeLimitInterval();
    });
    player.current.on('pause', function () {
      return stopTimeLimitInterval();
    });
    return function () {
      stopTimeLimitInterval();
      player.current.destroy();
    };
  }, [playerRef, startTimeLimitInterval, stopTimeLimitInterval]);
};
export default useTimeLimitCheck;